@@ -53,6 +53,9 @@ void log_output(const char *const format, ...)
     __attribute__(( format(printf, 1, 2) ));
 
 
+/** Log an error message */
+#define LOG_ERROR(...) log_error(__VA_ARGS__)
+
 /** Log an error message */
 void log_error(const char *const format, ...)
     __attribute__(( nonnull(1) ))
@@ -60,15 +63,23 @@ void log_error(const char *const format, ...)
 
 
 /** Log a warning message */
-void log_warning(const char *const format, ...)
-    __attribute__(( nonnull(1) ))
-    __attribute__(( format(printf, 1, 2) ));
+#define LOG_WARNING(...) log_warning(LOG_MODULE, __VA_ARGS__)
+
+/** Log a warning message */
+void log_warning(const char *const module,
+                 const char *const format, ...)
+    __attribute__(( nonnull(1, 2) ))
+    __attribute__(( format(printf, 2, 3) ));
 
 
 /** Log a verbose message */
-void log_verbose(const char *const format, ...)
-    __attribute__(( nonnull(1) ))
-    __attribute__(( format(printf, 1, 2) ));
+#define LOG_VERBOSE(...) log_verbose(LOG_MODULE, __VA_ARGS__)
+
+/** Log a verbose message */
+void log_verbose(const char *const module,
+                 const char *const format, ...)
+    __attribute__(( nonnull(1, 2) ))
+    __attribute__(( format(printf, 2, 3) ));
 
 
 /** Log a range of data */
@@ -81,7 +92,7 @@ void log_init(const int argc, char *const argv[])
     __attribute__(( nonnull(2) ));
 
 
-#endif /* BEEP_LOG_H */
+#endif /* !defined(BEEP_LOG_H) */
 
 
 /** @} */
